@@ -15,7 +15,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Port</source>
@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>儲 存</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation>正在連線</translation>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>斷開連線</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>確定刪除此設定？</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飛航模式</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>有線網路介面卡</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飛航模式</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>打開飛行模式將關閉無線網路、個人熱點和藍牙功能</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -460,7 +485,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Gateway</source>
@@ -495,7 +520,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
 </context>
 <context>
@@ -549,7 +574,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Gateway</source>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>應用程式代理伺服器</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飛航模式</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>網路詳情</translation>
@@ -689,7 +719,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Service</source>
@@ -919,7 +949,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Pwd Options</source>
@@ -994,7 +1024,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Key</source>
@@ -1052,7 +1082,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Authentication</source>
@@ -1272,7 +1302,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>CA Cert</source>
@@ -1347,7 +1377,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Auth Type</source>
@@ -1524,7 +1554,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Port</source>
@@ -1609,7 +1639,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Username</source>
@@ -1687,7 +1717,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>CA Cert</source>
@@ -1801,7 +1831,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Username</source>
@@ -1889,7 +1919,7 @@
     </message>
     <message>
         <source>Required</source>
-        <translation>必須</translation>
+        <translation>必填</translation>
     </message>
     <message>
         <source>Device MAC Addr</source>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>安全類型</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>頻段</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>聲道</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>頻段</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>界面</translation>
