@@ -1,4 +1,15 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
+<context>
+    <name>DeviceControllItem</name>
+    <message>
+        <source>Wireless Network</source>
+        <translation>Rede Wi-Fi</translation>
+    </message>
+    <message>
+        <source>Wired Network</source>
+        <translation>Rede Cabeada</translation>
+    </message>
+</context>
 <context>
     <name>NetworkPlugin</name>
     <message>
@@ -6,6 +17,31 @@
         <translation>Rede</translation>
     </message>
 </context>
+<context>
+    <name>WirelessItem</name>
+    <message>
+        <source>Connect to hidden network</source>
+        <translation>Conectar-se à rede oculta</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Senha</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <source>Connect</source>
+        <comment>button</comment>
+        <translation>Conectar</translation>
+    </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>Nome (SSID)</translation>
+    </message>
+</context>
 <context>
     <name>dde::network::NetworkDetails</name>
     <message>
@@ -24,14 +60,14 @@
         <source>Security Type</source>
         <translation>Tipo de Segurança</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Frequência</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Frequência</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interface</translation>
